@@ -21,9 +21,8 @@ sub get_request {
 	else {
 
 		our $use_cgi = $ENV {SCRIPT_NAME} =~ m{index\.pl} || ($ENV {GATEWAY_INTERFACE} =~ m{^CGI/} && !$ENV{MOD_PERL}) || $conf -> {use_cgi} || $preconf -> {use_cgi} || !$INC{'Apache/Request.pm'};
-
 		our $r   = $use_cgi ? new Eludia::Request ($preconf, $conf) : $_[0];
-		our $apr = $use_cgi ? $r : Apache::Request -> new ($r);
+		our $apr = $use_cgi ? $r : ($Eludia::Auth::NTLM::apr || Apache::Request -> new ($r));
 
 	}
 
@@ -174,6 +173,7 @@ sub handler {
 	my $parms = $apr -> parms;
 	undef %_REQUEST;
 	our %_REQUEST = %{$parms};
+
 	$_REQUEST {__skin} = '';
 	our $_REQUEST_TO_INHERIT = undef;
 
@@ -222,6 +222,8 @@ sub handler {
    	sql_reconnect ();
 
 	require_fresh ($_PACKAGE . 'Config');
+	
+	sql_assert_core_tables ();
 
 	if ($r -> uri =~ m{/(\w+)\.(css|gif|ico|js|html)$}) {
 
