@@ -1191,10 +1191,54 @@ sub draw_toolbar_input_select {
 	
 	my $name = $$options{name};
 	
-	$name = "_$name" if defined $options -> {other};
-	
+	if (defined $options -> {other}) {
+
+  	$name = "_$name";
+
+		$options -> {other} -> {width}  ||= 600;
+		$options -> {other} -> {height} ||= 400;
+
+		my $d_style_top = "d.style.top = " . (defined $options -> {other} -> {top} ? "${$$options{other}}{top};" : "this.offsetTop + this.offsetParent.offsetTop + this.offsetParent.offsetParent.offsetTop;");
+		my $d_style_left = "d.style.left = " . (defined $options -> {other} -> {left} ? "${$$options{other}}{left};" : "this.offsetLeft + this.offsetParent.offsetLeft + this.offsetParent.offsetParent.offsetLeft;");
+
+#				d.style.top   = this.offsetTop + this.offsetParent.offsetTop + this.offsetParent.offsetParent.offsetTop;
+#				d.style.left  = this.offsetLeft + this.offsetParent.offsetLeft + this.offsetParent.offsetParent.offsetLeft;
+
+		my $onchange = $_REQUEST {__windows_ce} ? "switchDiv(); loadSlaveDiv('${$$options{other}}{href}&select=$$options{name}');" : <<EOS;
+				var fname = '_$$options{name}_iframe';
+				var f = document.getElementById (fname);
+
+				var dname = '_$$options{name}_div';
+				var d = document.getElementById (dname);
+
+				f.src = '${$$options{other}}{href}&select=$$options{name}';
+
+				$d_style_top
+				$d_style_left
+
+				d.style.display = 'block';
+				this.style.display = 'none';
+
+				d.focus ();
+EOS
+
+		$options -> {onChange} .= <<EOJS;
+
+			if (this.options[this.selectedIndex].value == -1 && window.confirm ('$$i18n{confirm_open_vocabulary}')) {
+				$onchange
+			}
+			else {
+				submit();
+			}
+
+EOJS
+
+	}		
+
+	my $read_only = $options -> {read_only} ? 'disabled' : ''; 
+
 	$html .= <<EOH;
-		<select name="$name" id="${name}_select" onChange="$$options{onChange}" onkeypress="typeAhead()" style="visibility:expression((last_vert_menu && last_vert_menu [0]) || (window.top && window.top.last_vert_menu && window.top.last_vert_menu [0]) ? 'hidden' : '')">
+		<select name="$name" id="${name}_select" $read_only onChange="$$options{onChange}" onkeypress="typeAhead()" style="visibility:expression((last_vert_menu && last_vert_menu [0]) || (window.top && window.top.last_vert_menu && window.top.last_vert_menu [0]) ? 'hidden' : '')">
 EOH
 
 	if (defined $options -> {empty}) {
@@ -1207,28 +1251,18 @@ EOH
 		$html .= qq {<option value="$$value{id}" $$value{selected}>$$value{label}</option>};
 	}
 
-
-
-
-
-
 	if (defined $options -> {other}) {
 		$html .= qq {<option value=-1>${$$options{other}}{label}</option>};
 	}
 
 	$html .= '</select>';
 
-	my $width;
-	if (defined $options -> {other} -> {width}) {
-		$width = "${$$options{other}}{width}";
-#	} elsif (defined $options -> {other} -> {left}) {
-#		$width = "expression(this.offsetParent.offsetWidth)"; 
-#	} else {
-#		$width = "expression(getElementById('_$$options{name}_select').offsetParent.offsetWidth - 10)";
-	}
+
+
+
 	if (defined $options -> {other}) {
 		$html .= <<EOH;
-			<div id="_$$options{name}_div" style="{position:absolute; display:none; width:$width}">
+			<div id="_$$options{name}_div" style="{position:absolute; display:none;width:$options->{other}->{width}px">
 				<iframe name="_$$options{name}_iframe" id="_$$options{name}_iframe" width=100% height=${$$options{other}}{height} src="/i/0.html" application="yes">
 				</iframe>
 			</div>
@@ -1236,61 +1270,8 @@ EOH
 	}
 	
 	
-	
-	
-	
-	
-	
-	
-	
-	
-	
-	
-	
-	
 	$html .= "<td><img height=15 vspace=1 hspace=4 src='$_REQUEST{__static_url}/razd1.gif?$_REQUEST{__static_salt}' width=2 border=0></td>";
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
 	return $html;
 	
 }
@@ -1308,7 +1289,7 @@ sub draw_toolbar_input_checkbox {
 		$html .= ': ';
 	}
 
-	$html .= qq {<input type=checkbox value=1 $$options{checked} name="$$options{name}" onClick="submit()">};
+	$html .= qq {<input type=checkbox value=1 $$options{checked} name="$$options{name}" onClick="$$options{onClick}">};
 
 	$html .= "<td><img height=15 vspace=1 hspace=4 src='$_REQUEST{__static_url}/razd1.gif?$_REQUEST{__static_salt}' width=2 border=0></td>";
 	
@@ -1528,6 +1509,20 @@ EOH
 
 }
 
+################################################################################
+
+sub draw_dump_button {
+
+	return {
+		label  => 'Dump',
+		name   => '_dump',
+		href   => create_url () . '&__dump=1',
+		side   => 'right_items',
+		target => '_blank',
+		no_off => 1,
+	};
+}
+
 ################################################################################
 # MENUS
 ################################################################################
@@ -1663,7 +1658,7 @@ sub js_set_select_option {
 	return ($fallback_href || $i) unless $_REQUEST {select};
 	my $question = js_escape ($i18n -> {confirm_close_vocabulary} . ' ' . $item -> {label} . '?');
 	$name ||= '_' . $_REQUEST {select};
-	return 'javaScript:if (window.confirm(' . $question . ')) {parent.setSelectOption(' . js_escape ($name) . ', '	. $item -> {id} . ', ' . js_escape ($item -> {label}) . ');}';
+	return 'javaScript:if (window.confirm(' . $question . ')) {parent.setSelectOption(' . js_escape ($name) . ', '	. $item -> {id} . ', ' . js_escape ($item -> {label}) . ');} else {document.body.style.cursor = \'normal\'; nop ();}';
 }
 
 ################################################################################
@@ -1681,6 +1676,7 @@ sub draw_text_cell {
 	
 		$data -> {label} =~ s{^\s+}{};
 		$data -> {label} =~ s{\s+$}{};
+		$data -> {label} =~ s{\n}{<br>}gsm if $data -> {no_nobr};
 
 		$html .= qq {<img src='/i/_skins/Classic/status_$data->{status}->{icon}.gif' border=0 alt='$data->{status}->{label}' align=absmiddle hspace=5>} if $data -> {status};
 
@@ -1818,7 +1814,7 @@ sub draw_row_button {
 		$options -> {label} = "\&nbsp;[$$options{label}]\&nbsp;";
 	}
 	
-	my $vert_line = {label => $options -> {label}, href => $options -> {href}};
+	my $vert_line = {label => $options -> {label}, href => $options -> {href}, target => $options -> {target}};
 	$vert_line -> {label} =~ s{[\[\]]}{}g;
 	push @{$_SKIN -> {__current_row} -> {__types}}, $vert_line;
 		
@@ -1985,7 +1981,12 @@ sub draw_tree {
 
 	my ($_SKIN, $node_callback, $list, $options) = @_;
 	
+	push @{$_REQUEST{__include_js}}, 'dtree/dtree';
+	push @{$_REQUEST{__include_css}}, 'dtree/dtree';
+
 	my $menus;
+
+	my $target = $options -> {target} || '_content_iframe';
 	
 	my $html = <<EOH;
 	
@@ -2001,7 +2002,7 @@ sub draw_tree {
 				d = new dTree('d');
 				
 				d.config.iconPath = '/i/dtree/';
-				d.config.target = '_content_iframe';
+				d.config.target = '$target';
 				d.config.useStatusText = true;
 				d.icon.node = 'img/folderopen.gif';
 
@@ -2038,8 +2039,8 @@ sub draw_node {
 	my ($_SKIN, $options, $i) = @_;
 
 	my $menu = $i -> {__menu} ? "'$i'" : 'null';
-	
-	return "d.add($options->{id}, $options->{parent}, '$options->{label}', '$options->{href}', null, null, null, null, null, $menu);\n"
+	my $open = $options -> {open} ? 'true' : 'null';
+	return "d.add($options->{id}, $options->{parent}, '$options->{label}', '$options->{href}', null, null, null, null, $open, $menu);\n"
 
 }
 
