@@ -11,7 +11,7 @@ sub sql_weave_model {
 	foreach my $table_name ($db -> tables) {	
 		$table_name =~ s{.*?(\w+)\W*$}{$1}gsm;
 		next if $table_name eq $conf -> {systables} -> {log};
-		push @tables, $table_name;
+		push @tables, lc $table_name;
 	}
 		
 	foreach my $table_name (@tables) {
@@ -82,6 +82,30 @@ sub sql_weave_model {
 
 sub sql_assert_core_tables {
 
+	$db or return;
+
+	$model_update or die "\$db && !\$model_update ?!! Can't believe it.\n";
+
+	foreach (qw(
+		_db_model_checksums	
+		__voc_replacements	
+		__access_log		
+		__benchmarks		
+		__last_update		
+		__moved_links		
+		__required_files	
+		__screenshots		
+		cache_html		
+		log			
+		roles			
+		sessions		
+		users			
+	)) {
+		$conf -> {systables} -> {$_} ||= $_;
+	}
+
+	return if $model_update -> {core_ok};
+
 my $time = time;
 
 print STDERR "sql_assert_core_tables [$$] started...\n";
@@ -105,7 +129,7 @@ print STDERR "sql_assert_core_tables [$$] started...\n";
 		},
 	);
 
-	$model_update -> assert (tables => \%defs);
+	$model_update -> assert (tables => \%defs,core_voc_replacement_use => $conf -> {core_voc_replacement_use});
 
 	my %defs = (
 	
@@ -278,7 +302,7 @@ print STDERR "sql_assert_core_tables [$$] started...\n";
 		},
 	};
 
-	$model_update -> assert (tables => \%defs);
+	$model_update -> assert (tables => \%defs,core_voc_replacement_use => $conf -> {core_voc_replacement_use});
 
 	$model_update -> {core_ok} = 1;
 	
@@ -409,10 +433,6 @@ sub sql_reconnect {
 		$preconf -> {no_model_update} = 1;
 		
 	}
-	
-	if ($driver_name =~ m/ORACLE/i) {
-		sql_do ("ALTER SESSION SET NLS_NUMERIC_CHARACTERS='.,' TIME_ZONE = '+4:00' NLS_DATE_FORMAT = 'YYYY-MM-DD HH24:MI:SS'");		
-	}
 
 	our %sts = ();
 
@@ -717,9 +737,9 @@ sub assert_fake_key {
 	
 		$table_name => {
 			keys => {fake => 'fake'},
-		}
+		},
 	
-	});
+	},core_voc_replacement_use => $conf -> {core_voc_replacement_use});
 
 }
 
@@ -733,7 +753,7 @@ sub delete_fakes {
 
 	return if is_recyclable ($table_name);
 	
-	assert_fake_key ($table_name);
+	assert_fake_key ($table_name,core_voc_replacement_use => $conf -> {core_voc_replacement_use});
 	
 	my $ids = sql_select_ids (<<EOS);
 		SELECT
