@@ -2,6 +2,7 @@ no strict;
 no warnings;
 
 #use DBD::Oracle qw(:ora_types);
+#use Carp qw(cluck);
 
 ################################################################################
 
@@ -236,7 +237,7 @@ sub sql_select_all_cnt {
 		$cnt = (@$temp + 0);
 	}
 	else {
-		$sql =~ s/SELECT.*FROM/SELECT COUNT(*) FROM/igsm;
+		$sql =~ s/SELECT.*?FROM/SELECT COUNT(*) FROM/ism;
 		$cnt = sql_select_scalar ($sql, @params);
 	}
 			
@@ -1091,4 +1092,4 @@ sub sql_select_ids {
 	return wantarray ? (join(',', @ids), $sql) : join(',', @ids);
 }
 
-1;
\ No newline at end of file
+1;
