@@ -440,5 +440,19 @@ sub keep_alive {
 	my $sid = shift;
 	sql_do ("UPDATE $conf->{systables}->{sessions} SET ts = ? WHERE id = ? ", int(time), $sid);
 }
+################################################################################
+
+sub sql_select_ids {
+	my ($sql, @params) = @_;
+
+	my @ids = grep {$_ > 0} sql_select_col ($sql, @params);
+	push @ids, -1;
+
+	foreach my $parameter (@params) {
+		$sql =~ s/\?/'$parameter'/ism;
+	}
+
+	return wantarray ? (join(',', @ids), join(',', @ids)) : join(',', @ids);
+}
 
 1;
